<?php
// Leer el archivo de preguntas
$preguntas = file('preguntas.txt');

// Convertir cada bloque de preguntas en un array para manejar mejor los datos
$preguntasProcesadas = [];
$preguntaActual = [];

foreach ($preguntas as $linea) {
    // Eliminar espacios en blanco y saltos de línea
    $linea = trim($linea);

    // Si la línea está vacía, es el fin de un bloque de pregunta
    if (empty($linea)) {
        if (!empty($preguntaActual)) {
            $preguntasProcesadas[] = $preguntaActual;
        }
        $preguntaActual = [];
    } else {
        // Procesar las etiquetas y los valores
        if (strpos($linea, 'Nombre:') !== false) {
            $preguntaActual['nombre'] = trim(str_replace('Nombre:', '', $linea));
        } elseif (strpos($linea, 'Email:') !== false) {
            $preguntaActual['email'] = trim(str_replace('Email:', '', $linea));
        } elseif (strpos($linea, 'Pregunta:') !== false) {
            $preguntaActual['pregunta'] = trim(str_replace('Pregunta:', '', $linea));
        } elseif (strpos($linea, 'Estado:') !== false) {
            $preguntaActual['estado'] = trim(str_replace('Estado:', '', $linea));
        }
    }
}

// Agregar la última pregunta si no se ha agregado
if (!empty($preguntaActual)) {
    $preguntasProcesadas[] = $preguntaActual;
}

// Filtrar por estado (pendientes, respondidas, ignoradas)
$filtroEstado = isset($_GET['filtro']) ? $_GET['filtro'] : 'todas';  // Si no hay filtro, mostrar todas

?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Enlace a Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@700&display=swap" rel="stylesheet">
    <title>Panel de Moderador - Preguntas</title>
    <style>
        .header {
            text-align: center;
            margin-bottom: 20px;
        }
        .header img {
            max-width: 295px; /* Ajusta el tamaño del logo */
            margin-bottom: 10px;
        }
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
            background-color: #f4f4f4;
        }
        h1 {
            font-family: 'Poppins', sans-serif; /* Usar la fuente de Google */
            font-weight: bold; /* Negrita */
            margin: 0;
        }
        h3 {
            font-family: 'Poppins', sans-serif; /* Usar la fuente de Google */
            font-weight: bold; /* Negrita */
            margin: 5px 0 20px; /* Añadir margen para separar el subtítulo del contenido */
        }
		h4 {
            color: #555;
            font-size: 0.9em;
        }
        .container {
            max-width: 900px;
            margin: 0 auto;
        }
        .pregunta {
            background-color: white;
            margin-bottom: 20px;
            padding: 15px;
            border-radius: 5px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
            border-left: 4px solid #2196F3;
            transition: border-color 0.3s ease;
        }
        .pregunta:nth-child(even) {
            border-color: #FF5722;
        }
        .pregunta p {
            margin: 0;
            padding: 0;
        }
        .pregunta-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            margin-bottom: 10px;
        }
        .pregunta-numero {
            font-weight: bold;
            color: #666;
        }
        .pregunta-estado {
            color: #555;
            font-size: 0.9em;
        }
        .acciones {
            display: flex;
            gap: 10px;
        }
        .btn {
            padding: 8px 15px;
            border: none;
            color: white;
            cursor: pointer;
            border-radius: 4px;
            margin-right: 10px;
            font-size: 0.9em;
        }
        .btn-respondida {
            background-color: #4CAF50;
        }
        .btn-ignorar {
            background-color: #f44336;
        }
        .btn-pendiente {
            background-color: #FFC107;
        }
        .pregunta-detalle {
            margin-top: 10px;
        }
        .pregunta-detalle p {
            margin-bottom: 5px;
        }
        .filtro-container {
            margin-bottom: 20px;
            text-align: center;
        }
        .filtro-container select {
            padding: 10px;
            font-size: 1rem;
        }
        .footer {
            text-align: center;
            margin-top: 20px;
            font-size: 0.8rem; /* Tamaño de fuente pequeño */
            color: #555; /* Color gris para el texto */
        }
    </style>
</head>
<body>
        <div class="header">
        <img src="logo.png" alt="Logo de la Empresa"> 
        <h1>Panel Reforma del Código Laboral</h1>
			<h4>Jueves 26 de sept, 2024.</h4>
			<h3>Panel de Moderador - Preguntas</h3>
    </div>

    
    <!-- Filtro de preguntas por estado -->
    <div class="filtro-container">
        <form method="GET" action="moderador.php">
            <label for="filtro">Filtrar por estado:</label>
            <select name="filtro" id="filtro" onchange="this.form.submit()">
                <option value="todas" <?php if($filtroEstado == 'todas') echo 'selected'; ?>>Todas</option>
                <option value="Pendiente" <?php if($filtroEstado == 'Pendiente') echo 'selected'; ?>>Pendientes</option>
                <option value="Respondida" <?php if($filtroEstado == 'Respondida') echo 'selected'; ?>>Respondidas</option>
                <option value="Ignorada" <?php if($filtroEstado == 'Ignorada') echo 'selected'; ?>>Ignoradas</option>
            </select>
        </form>
    </div>

    <div class="container">
        <?php 
        // Mostrar preguntas según el filtro seleccionado
        foreach ($preguntasProcesadas as $index => $pregunta): 
            // Extraer la información de la pregunta
            $nombre = isset($pregunta['nombre']) ? htmlspecialchars($pregunta['nombre']) : '';
            $email = isset($pregunta['email']) ? htmlspecialchars($pregunta['email']) : '';
            $preguntaTexto = isset($pregunta['pregunta']) ? nl2br(htmlspecialchars($pregunta['pregunta'])) : ''; // Cambiado para usar nl2br
            $estado = isset($pregunta['estado']) ? htmlspecialchars($pregunta['estado']) : 'Pendiente';  // Por defecto 'Pendiente' si no está definido

            // Aplicar filtro
            if ($filtroEstado !== 'todas' && $estado !== $filtroEstado) {
                continue;  // Saltar preguntas que no coinciden con el filtro
            }
        ?>

            <div class="pregunta">
                <div class="pregunta-header">
                    <span class="pregunta-numero">#<?php echo $index + 1; ?></span>
                    <span class="pregunta-estado"><?php echo $estado; ?></span>
                    <div class="acciones">
                        <form action="actualizar_estado.php" method="POST" style="display: inline;">
                            <input type="hidden" name="index" value="<?php echo $index; ?>">
                            <input type="hidden" name="estado" value="Respondida">
                            <button type="submit" class="btn btn-respondida">M.Respondida</button>
                        </form>
                        <form action="actualizar_estado.php" method="POST" style="display: inline;">
                            <input type="hidden" name="index" value="<?php echo $index; ?>">
                            <input type="hidden" name="estado" value="Ignorada">
                            <button type="submit" class="btn btn-ignorar">Ignorar</button>
                        </form>
                        <form action="actualizar_estado.php" method="POST" style="display: inline;">
                            <input type="hidden" name="index" value="<?php echo $index; ?>">
                            <input type="hidden" name="estado" value="Pendiente">
                            <button type="submit" class="btn btn-pendiente">M.Pendiente</button>
                        </form>
                    </div>
                </div>
                
                <div class="pregunta-detalle">
                    <p><strong>Nombre:</strong> <?php echo $nombre; ?></p>
                    <p><strong>Email:</strong> <?php echo $email; ?></p>
                    <p><strong>Pregunta:</strong> <?php echo $preguntaTexto; ?></p>
                </div>
            </div>

        <?php endforeach; ?>
    </div>
	    <footer class="footer">
        Copyright ANEIH 2024<br>
        Av. Tiradentes 14, Edif. Alfonso Comercial, 7mo piso, Ens. Naco, Santo Domingo 10119<br>
        Teléfono (809) 560-2160 - Sistema Versión 1.0 - 2024-09-25
    </footer>
</body>
</html>
